@@ -23,10 +23,6 @@
 #'
 #' @inheritParams bde_catalog_update
 #'
-#' @note
-#'  From 1 July 2021, the contents of the publication Economic Indicators will
-#'  gradually be migrated to the Statistical Bulletin. From June 2022, the
-#'  Economic Indicators section will no longer be available.
 #'
 #' @details
 #' Accepted values for `catalog` are:
@@ -36,8 +32,6 @@
 #' t <- tibble::tribble(
 #' ~CODE, ~PUBLICATION, ~UPDATEFREQUENCY, ~FREQUENCY,
 #' "**BE**", "Statistical Bulletin", "Daily", "Monthly",
-#' "**CF**", "Financial Accounts of the Spanish Economy", "Quarterly", "Annual",
-#' "**IE** (see **Note**)", "Economic Indicators", "Daily", "Monthly",
 #' "**SI**", "Summary Indicators", "Daily", "Daily",
 #' "**TC**", "Exchange Rates", "Daily", "Daily",
 #' "**TI**", "Interest Rates", "Daily", "Daily",
@@ -69,7 +63,7 @@ bde_catalog_load <-
            verbose = FALSE) {
     # Validate
     valid_catalogs <-
-      c("BE", "CF", "IE", "SI", "TC", "TI", "PB", "ALL")
+      c("BE", "SI", "TC", "TI", "PB", "ALL")
     stopifnot(
       catalog %in% valid_catalogs,
       length(catalog) == 1,
@@ -192,7 +186,6 @@ bde_catalog_load <-
           bde_parse_dates(final_catalog[[field]])
       }
     }
-
     return(final_catalog)
   }
 
@@ -226,16 +219,16 @@ bde_catalog_load <-
 #'
 #' t <- tibble::tribble(
 #' ~CODE, ~PUBLICATION, ~UPDATEFREQUENCY, ~FREQUENCY,
-#' "BE", "Statistical Bulletin", "Daily", "Monthly",
-#' "CF", "Financial Accounts of the Spanish Economy", "Quarterly", "Annual",
-#' "IE", "Economic Indicators", "Daily", "Monthly",
-#' "SI", "Summary Indicators", "Daily", "Daily",
-#' "TC", "Exchange Rates", "Daily", "Daily",
-#' "TI", "Interest Rates", "Daily", "Daily",
-#' "PB", "Bank Lending Survey", "Quarterly", "Quarterly",
+#' "**BE**", "Statistical Bulletin", "Daily", "Monthly",
+#' "**SI**", "Summary Indicators", "Daily", "Daily",
+#' "**TC**", "Exchange Rates", "Daily", "Daily",
+#' "**TI**", "Interest Rates", "Daily", "Daily",
+#' "**PB**", "Bank Lending Survey", "Quarterly", "Quarterly",
 #' )
 #'
-#' names(t) <- c("CODE","PUBLICATION", "UPDATE FREQUENCY", "FREQUENCY")
+#' names(t) <- paste0("**",
+#'   c("CODE","PUBLICATION", "UPDATE FREQUENCY", "FREQUENCY"),
+#'   "**")
 #'
 #' knitr::kable(t)
 #'
@@ -253,7 +246,7 @@ bde_catalog_update <-
            verbose = FALSE) {
     # Validate
     valid_catalogs <-
-      c("BE", "CF", "IE", "SI", "TC", "TI", "PB", "ALL")
+      c("BE", "SI", "TC", "TI", "PB", "ALL")
     stopifnot(
       catalog %in% valid_catalogs,
       is.null(cache_dir) || is.character(cache_dir),
